# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-05-06 07:43
from __future__ import unicode_literals

from django.db import migrations, models
from django.db.models.deletion import CASCADE

from events.models import Location


KEYNOTE_EVENT_KWARGS = [
    {'speaker_name': 'Amber Brown', 'slug': 'amber-brown'},
    {'speaker_name': 'Audrey Tang', 'slug': 'audrey-tang'},
    {'speaker_name': 'Jim Huang', 'slug': 'jim-huang'},
    {'speaker_name': 'Paul Hildebrandt', 'slug': 'paul-hildebrandt'},
    {'speaker_name': 'Steve Dower', 'slug': 'steve-dower'},
]


def add_keynote_events(apps, schema_editor):
    KeynoteEvent = apps.get_model('events', 'KeynoteEvent')
    db_alias = schema_editor.connection.alias
    KeynoteEvent.objects.using(db_alias).bulk_create([
        KeynoteEvent(location=Location.ALL, **kwargs)
        for kwargs in KEYNOTE_EVENT_KWARGS
    ])


class Migration(migrations.Migration):

    dependencies = [
        ('events', '0003_time_location_in_sponsoredevent'),
    ]

    operations = [
        migrations.CreateModel(
            name='KeynoteEvent',
            fields=[
                ('id', models.AutoField(
                    auto_created=True, primary_key=True, serialize=False,
                    verbose_name='ID',
                )),
                ('location', models.CharField(
                    blank=True, db_index=True, max_length=6, null=True,
                    verbose_name='location', choices=[
                        ('2-all', 'All rooms'),
                        ('3-r012', 'R0, R1, R2'),
                        ('4-r0', 'R0'),
                        ('5-r1', 'R1'),
                        ('6-r2', 'R2'),
                        ('1-r3', 'R3'),
                    ],
                )),
                ('speaker_name', models.CharField(
                    max_length=100, verbose_name='speaker name',
                )),
                ('slug', models.SlugField(
                    help_text=(
                        "This is used to link to the speaker's introduction "
                        "on the Keynote page, e.g. 'liang2' will link to "
                        "'/None/events/keynotes/#keynote-speaker-liang2'."
                    ),
                    verbose_name='slug',
                )),
            ],
            options={
                'verbose_name_plural': 'keynote events',
                'verbose_name': 'keynote event',
            },
        ),
        migrations.AddField(
            model_name='keynoteevent',
            name='begin_time',
            field=models.ForeignKey(
                blank=True, null=True, on_delete=CASCADE,
                related_name='begined_keynoteevent_set',
                to='events.Time', verbose_name='begin time',
            ),
        ),
        migrations.AddField(
            model_name='keynoteevent',
            name='end_time',
            field=models.ForeignKey(
                blank=True, null=True, on_delete=CASCADE,
                related_name='ended_keynoteevent_set',
                to='events.Time', verbose_name='end time',
            ),
        ),

        migrations.RunPython(
            code=add_keynote_events,
            reverse_code=migrations.RunPython.noop,
        ),
    ]
